@@ -16,11 +16,11 @@ Text::JSON::Nibble - Nibble complete JSON objects from buffers
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 =head1 WARNING
 
@@ -145,6 +145,9 @@ sub digest {
 	# Save the current state for if we are dealing with a stream elsewhere.
 	my $stateBackup = $self->{state} if ($self->{state});
 	
+	# Start with a fresh state
+	$self->reset;
+	
 	# Load the digest data into the processor
 	$self->process($data);
 	
